==> cejs-4.5.4.tgz: package/application/locale/resources/sv-SE.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2022.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"Espa\u00f1a": "Spanien",
	"Calendrier r\u00e9publicain": "Franska revolutionskalendern",
	"untranslated message count": "1000+",
	"\u6e05\u9664\u8a0a\u606f": "Rensa logg",
	"\u986f\u793a/\u96b1\u85cf\u8a0a\u606f": "Visa / d\u00f6lj logg",
	"Load failed": "Kunde inte ladda",
	"\u8a0a\u606f\u63d0\u793a\u8207\u7d00\u9304\u6b04": "Journalpanel",
	"\u5730\u7406\u5ea7\u6a19\uff1a": "Koordinater: ",
	"\u81ea\u8a02\u8f38\u51fa\u683c\u5f0f": "Anpassa utmatningsformat",
	"\u7d93\u5ea6\uff1a": "Latitud: ",
	"\u7def\u5ea6\uff1a": "Longitud: ",
	"\u8f38\u51fa\u683c\u5f0f": "Utmatningsformat",
	"\u524d\u7db4": "prefix",
	"\u6642\u5340\uff1a": "Tidszon: ",
	"\u8acb\u6ce8\u610f\uff1a\u672c\u6b04\u50c5\u4f9b\u958b\u767c\u4eba\u54e1\u4f7f\u7528\u3002": "VARNING: Endast f\u00f6r utvecklare.",
	"\u6279\u6b21\u8f49\u63db": "BUNT",
	"Loading...": "Laddar...",
	"\u7d04%1\u5e74": "ungef. %1",
	"\u1019\u103c\u1014\u103a\u1019\u102c": "Myanmar",
	"Vi\u1ec7t Nam": "Vietnam",
	"Unpin": "L\u00f6sg\u00f6r",
	"Pin": "F\u00e4st",
	"\u9664\u53bb\u6b64\u6b04": "Ta bort kolumnen",
	"\u5206\u985e": "Gruppera",
	"%1/%2/%3": "%1/%2/%3",
	"%1 BCE": "%1 f.v.t.",
	"%1 CE": "%1 f.v.t.",
	"\u5e74\u8b5c": "kalenderdatum",
	"\u66c6\u8b5c": "KALENDERTABELL",
	"\u5171\u6709 %1 \u500b\u6642\u6bb5{{PLURAL:%1|\u7d00\u9304}}": "%1 registreringar",
	"\u5171\u6709 %1 \u500b\u5e74\u6bb5{{PLURAL:%1|\u7d00\u9304}}": "%1 \u00e5r",
	"\u7121\u53ef\u4f9b\u5217\u51fa\u4e4b\u66c6\u8b5c\uff01": "Ingen kalender att lista!",
	"\u5617\u8a66\u52a0\u6ce8\u65e5\u671f": "Testa att tillfoga datum",
	"\u5168\u4e0d\u9078": "Ta bort ALLT",
	"\u589e\u52a0\u6b64\u6b04": "L\u00e4gg till kolumnen",
	"\u8cc7\u6599\u5716\u5c64": "Datalager",
	"\u5c0e\u89bd\u5217\uff1a": "Navigering: ",
	"\u6240\u6709\u570b\u5bb6": "Alla l\u00e4nder",
	"\u6e2c\u8a66\u7bc4\u4f8b": "EXEMPEL",
	"\u8f38\u5165\u7d00\u9304": "REGISTRERING",
	"\u4f7f\u7528\u8aaa\u660e": "KONCEPT",
	"\u7d00\u5e74\u7dda\u5716": "TIDSLINJE",
	"\u8a2d\u5b9a": "KONFIGURERING",
	"\u6a19\u6ce8\u6587\u672c": "TAGGNING",
	"\u66c6\u6578\u8655\u7406": "UTVECKLING",
	"\u554f\u984c\u56de\u5831": "\u00c5TERKOPPLING",
	"Julian Day Number": "Julianskt datumnummer",
	"France": "Frankrike",
	"Great Britain": "Storbritannien",
	"Spain": "Spanien",
	"\u63a1\u7528\u66c6\u6cd5": "Kalender som anv\u00e4nds",
	"\u51fa\u5178": "Datak\u00e4lla",
	"\u541b\u4e3b\u540d": "Personnamn",
	"\u8868\u5b57": "Artighetsnamn",
	"\u541b\u4e3b\u865f": "Artistnamn",
	"\u8af1": "Riktigt namn",
	"\u8ae1": "Postumt namn",
	"\u5edf\u865f": "Tempelnamn",
	"\u51fa\u751f": "F\u00f6dd",
	"\u901d\u4e16": "D\u00f6d",
	"\u5728\u4f4d": "Styre",
	"\u52a0\u5195": "Kr\u00f6ning",
	"\u524d\u4efb": "F\u00f6reg\u00e5ngare",
	"\u7e7c\u4efb": "Eftertr\u00e4dare",
	"\u7236\u89aa": "Far",
	"\u6bcd\u89aa": "Mor",
	"\u914d\u5076": "Make/maka",
	"\u5c55\u793a\u7dda\u5716": "Visar tidslinje",
	"\u7d00\u5e74 %1": "Era %1",
	"Initializing...": "Initierar...",
	"\u5df2\u8f09\u5165 %1 \u7b46\u8cc7\u6599\u3002": function (domain_name, arg) { return '%1 ' + (1 < arg[1] ? 'inlägg' : 'inlägg') + ' laddad.'; },
	"Aries": "V\u00e4duren",
	"Taurus": "Oxen",
	"Gemini": "Tvillingarna",
	"Cancer": "Kr\u00e4ftan",
	"Leo": "Lejonet",
	"Virgo": "Jungfrun",
	"Libra": "V\u00e5gen",
	"Scorpio": "Skorpionen",
	"Sagittarius": "Skytten",
	"Capricorn": "Stenbocken",
	"Aquarius": "Vattumannen",
	"Pisces": "Fiskarna",
	"\u6708\u76f8": "m\u00e5nfas",
	"\u661f\u671f": "Veckodag",
	"Julian Date": "Julianskt datum",
	"\u9031\u65e5\u671f": "Veckodatum",
	"Unix time": "Unixtid",
	"calendar": "kalender",
	"Gregorian calendar": "Gregorianska kalendern",
	"Julian calendar": "Julianska kalendern",
	"\u66c6\u6ce8": "Kalenderanteckning",
	"\u4e2d\u570b": "Kina",
	"Loading %1%...": "Laddar %1%...",
	"finished": "klar",
	"No changes.": "Inga \u00e4ndringar.",
	"no page modified,": "ingen sida modifierad,",
	"\u4e2d\u6587\u6578\u5b57": "Till kinesiska siffror",
	"astronomy": "astronomi",
	"log-type-debug": "fels\u00f6kning",
	"log-type-em": "emfas",
	"log-type-error": "fel",
	"log-type-fatal": "kritisk",
	"log-type-info": "info",
	"log-type-log": "logg",
	"log-type-trace": "sp\u00e5r",
	"log-type-warn": "varna",
	"Not Yet Implemented!": "Inte \u00e4nnu implementerad!",
	"\u6240\u6307\u5b9a\u4e4b domain [%1] \u5c1a\u672a\u8f09\u5165\uff0c\u82e5\u6709\u5fc5\u8981\u8acb\u4f7f\u7528\u5f37\u5236\u8f09\u5165 flag\u3002": "Angiven dom\u00e4n [%1] har \u00e4nnu inte laddats. Du kan beh\u00f6va ange FORCE-flagga.",
	"Language": "Spr\u00e5k",
	"Content is empty": "Inneh\u00e5llet \u00e4r tomt",
	"Content is not settled": "Inneh\u00e5llet har inte etablerats",
	"Abandon change": "\u00d6verge \u00e4ndring",
	"No reason provided": "Ingen anledning gavs",
	"Continue key": "Forts\u00e4ttningsnyckel",
	"no change": "ingen \u00e4ndring",
	"finished: %1": "klar: %1",
	"%1 elapsed, %3 at %2": "%1 passerad, %3 vid %2",
	"First, it takes %1 to get %2 {{PLURAL:%2|page|pages}}.": "F\u00f6rst tar den %1 och f\u00e5r %2 sidor.",
	"%1 {{PLURAL:%2|page|pages}} processed": "%1 sidor bearbetade",
	"%1 {{PLURAL:%1|page|pages}} have not changed,": "%1 sidor har inte \u00e4ndrats,",
	"%1 elapsed.": "%1 passerad.",
	"'''Stopped''', give up editing.": "'''Stannade''', \u00f6verge redigering.",
	"function": "funktion",
	"number": "nummer",
	"Contents": "Inneh\u00e5ll",
	"%1 {{PLURAL:%1|year|years}} and %2 {{PLURAL:%2|month|months}}": "%1 \u00e5r %2 m",
	"%1 Y %2 M": "%1 \u00e5r %2 m",
	"%1 {{PLURAL:%1|year|years}}": "%1 \u00e5r",
	"%1 Y": "%1 \u00e5r",
	"%1 {{PLURAL:%1|month|months}}": "%1 m",
	"%1 M": "%1 m",
	"%1 {{PLURAL:%1|millisecond|milliseconds}}": "%1 ms",
	"%1 ms": "%1 ms",
	"%1 {{PLURAL:%1|second|seconds}}": "%1 s",
	"%1 s": "%1 s",
	"%1 {{PLURAL:%1|minute|minutes}}": "%1 min",
	"%1 min": "%1 min",
	"%1 {{PLURAL:%1|hour|hours}}": "%1 tm",
	"%1 hr": "%1 tm",
	"%1 {{PLURAL:%1|day|days}}": "%1 d",
	"%1 d": "%1 d",
	"2 days before yesterday, %H:%M": "I f\u00f6rrf\u00f6rrg\u00e5r, %H:%M",
	"the day before yesterday, %H:%M": "i f\u00f6rrg\u00e5r, %H:%M",
	"yesterday, %H:%M": "ig\u00e5r, %H:%M",
	"today, %H:%M": "idag, %H:%M",
	"tomorrow, %H:%M": "imorgon, %H:%M",
	"the day after tomorrow, %H:%M": "i \u00f6vermorgon, %H:%M",
	"2 days after tomorrow, %H:%M": "i \u00f6ver\u00f6vermorgon, %H:%M",
	"3 days after tomorrow, %H:%M": "om fyra dagar, %H:%M",
	"now": "nu",
	"several seconds ago": "flera sekunder sedan",
	"soon": "snart",
	"%1 {{PLURAL:%1|second|seconds}} ago": "%1 sekunder sen",
	"%1 {{PLURAL:%1|second|seconds}} later": "%1 sekunder senare",
	"%1 {{PLURAL:%1|minute|minutes}} ago": "%1 minuter sedan",
	"%1 {{PLURAL:%1|minute|minutes}} later": "%1 minuter senare",
	"%1 {{PLURAL:%1|hour|hours}} ago": "%1 timme sedan",
	"%1 {{PLURAL:%1|hour|hours}} later": "%1 timme senare",
	"%1 {{PLURAL:%1|day|days}} ago": "%1 dag sedan",
	"%1 {{PLURAL:%1|day|days}} later": "%1 dagar senare",
	"%1 {{PLURAL:%1|week|weeks}} ago": "%1 veckor sedan",
	"%1 {PLURAL:%1|week|weeks}} later": "%1 veckor senare",
	"\u5e74\u865f": "Datum i era",
	"\u8a3b": "Anteckning",
	"\u7d00\u5e74": "Erans namn",
	"\u8df3\u904e [%1]\uff1a\u672c[%2]\u50c5\u4f9b\u53c3\u7167\u7528\u3002": "Hoppa \u00f6ver [%1]: %2 ska bara anv\u00e4ndas f\u00f6r referenser.",
	"\u7409\u7403": "Ryukyu",
	"\u65e5\u672c": "Japan",
	"\ud55c\uad6d": "Korea",
	"B\u1eafc thu\u1ed9c": "Kinesisk dominans \u00f6ver Vietnam",
	"Th\u1eddi k\u1ef3 \u0111\u1ed9c l\u1eadp": "Sen dynastisk epok",
	"\u0e44\u0e17\u0e22": "Thailand",
	"India": "Indien",
	"Persia": "Persien",
	"\u039c\u03b1\u03ba\u03b5\u03b4\u03bf\u03bd\u03af\u03b1": "Makedonien",
	"\u1f08\u03b8\u1fc6\u03bd\u03b1\u03b9": "Klassiska Aten",
	"\u03a3\u03c0\u03ac\u03c1\u03c4\u03b7": "Sparta",
	"\u2191Back to TOC": "\u2191Tillbaka till inneh\u00e5llsf\u00f6rteckning",
	"Contents of [%1]": "Inneh\u00e5ll av [%1]",
	"expand": "visa",
	"collapse": "d\u00f6lj",
	"Illegal %1: [%2]": "Otill\u00e5ten %1: [%2]",
	"debug level": "fels\u00f6kningsniv\u00e5"
},
"sv-SE");

==> cejs-4.5.6.tgz: package/application/locale/resources/sv-SE.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2023.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"Espa\u00f1a": "Spanien",
	"Calendrier r\u00e9publicain": "Franska revolutionskalendern",
	"untranslated message count": "1000+",
	"\u6e05\u9664\u8a0a\u606f": "Rensa logg",
	"\u986f\u793a/\u96b1\u85cf\u8a0a\u606f": "Visa / d\u00f6lj logg",
	"Load failed": "Kunde inte ladda",
	"\u8a0a\u606f\u63d0\u793a\u8207\u7d00\u9304\u6b04": "Journalpanel",
	"\u5730\u7406\u5ea7\u6a19\uff1a": "Koordinater: ",
	"\u81ea\u8a02\u8f38\u51fa\u683c\u5f0f": "Anpassa utmatningsformat",
	"\u7def\u5ea6\uff1a": "Latitud: ",
	"\u7d93\u5ea6\uff1a": "Longitud: ",
	"\u8f38\u51fa\u683c\u5f0f": "Utmatningsformat",
	"\u524d\u7db4": "prefix",
	"\u6642\u5340\uff1a": "Tidszon: ",
	"\u8acb\u6ce8\u610f\uff1a\u672c\u6b04\u50c5\u4f9b\u958b\u767c\u4eba\u54e1\u4f7f\u7528\u3002": "VARNING: Endast f\u00f6r utvecklare.",
	"\u6279\u6b21\u8f49\u63db": "BUNT",
	"Loading...": "Laddar...",
	"\u7d04%1\u5e74": "ungef. %1",
	"\u1019\u103c\u1014\u103a\u1019\u102c": "Myanmar",
	"Vi\u1ec7t Nam": "Vietnam",
	"Unpin": "L\u00f6sg\u00f6r",
	"Pin": "F\u00e4st",
	"\u9664\u53bb\u6b64\u6b04": "Ta bort kolumnen",
	"\u5206\u985e": "Gruppera",
	"%1/%2/%3": "%1/%2/%3",
	"%1 BCE": "%1 f.v.t.",
	"%1 CE": "%1 f.v.t.",
	"\u5e74\u8b5c": "kalenderdatum",
	"\u66c6\u8b5c": "KALENDERTABELL",
	"\u5171\u6709 %1 \u500b\u6642\u6bb5{{PLURAL:%1|\u7d00\u9304}}": "%1 registreringar",
	"\u5171\u6709 %1 \u500b\u5e74\u6bb5{{PLURAL:%1|\u7d00\u9304}}": "%1 \u00e5r",
	"\u7121\u53ef\u4f9b\u5217\u51fa\u4e4b\u66c6\u8b5c\uff01": "Ingen kalender att lista!",
	"\u5617\u8a66\u52a0\u6ce8\u65e5\u671f": "Testa att tillfoga datum",
	"\u5168\u4e0d\u9078": "Ta bort ALLT",
	"\u589e\u52a0\u6b64\u6b04": "L\u00e4gg till kolumnen",
	"\u8cc7\u6599\u5716\u5c64": "Datalager",
	"\u5c0e\u89bd\u5217\uff1a": "Navigering: ",
	"\u6240\u6709\u570b\u5bb6": "Alla l\u00e4nder",
	"\u6e2c\u8a66\u7bc4\u4f8b": "EXEMPEL",
	"\u8f38\u5165\u7d00\u9304": "REGISTRERING",
	"\u4f7f\u7528\u8aaa\u660e": "KONCEPT",
	"\u7d00\u5e74\u7dda\u5716": "TIDSLINJE",
	"\u8a2d\u5b9a": "KONFIGURERING",
	"\u6a19\u6ce8\u6587\u672c": "TAGGNING",
	"\u66c6\u6578\u8655\u7406": "UTVECKLING",
	"\u554f\u984c\u56de\u5831": "\u00c5TERKOPPLING",
	"Julian Day Number": "Julianskt datumnummer",
	"France": "Frankrike",
	"Great Britain": "Storbritannien",
	"Spain": "Spanien",
	"\u63a1\u7528\u66c6\u6cd5": "Kalender som anv\u00e4nds",
	"\u51fa\u5178": "Datak\u00e4lla",
	"\u541b\u4e3b\u540d": "Personnamn",
	"\u8868\u5b57": "Artighetsnamn",
	"\u541b\u4e3b\u865f": "Artistnamn",
	"\u8af1": "Riktigt namn",
	"\u8ae1": "Postumt namn",
	"\u5edf\u865f": "Tempelnamn",
	"\u51fa\u751f": "F\u00f6dd",
	"\u901d\u4e16": "D\u00f6d",
	"\u5728\u4f4d": "Styre",
	"\u52a0\u5195": "Kr\u00f6ning",
	"\u524d\u4efb": "F\u00f6reg\u00e5ngare",
	"\u7e7c\u4efb": "Eftertr\u00e4dare",
	"\u7236\u89aa": "Far",
	"\u6bcd\u89aa": "Mor",
	"\u914d\u5076": "Make/maka",
	"\u5c55\u793a\u6642\u9593\u7dda\u5716": "Visar tidslinje",
	"\u7d00\u5e74 %1": "Era %1",
	"Initializing...": "Initierar...",
	"\u5df2\u8f09\u5165 %1 \u7b46\u8cc7\u6599\u3002": function (domain_name, arg) { return '%1 ' + (1 < arg[1] ? 'inlägg' : 'inlägg') + ' laddad.'; },
	"Aries": "V\u00e4duren",
	"Taurus": "Oxen",
	"Gemini": "Tvillingarna",
	"Cancer": "Kr\u00e4ftan",
	"Leo": "Lejonet",
	"Virgo": "Jungfrun",
	"Libra": "V\u00e5gen",
	"Scorpio": "Skorpionen",
	"Sagittarius": "Skytten",
	"Capricorn": "Stenbocken",
	"Aquarius": "Vattumannen",
	"Pisces": "Fiskarna",
	"\u6708\u76f8": "m\u00e5nfas",
	"\u661f\u671f": "Veckodag",
	"Julian Date": "Julianskt datum",
	"\u9031\u65e5\u671f": "Veckodatum",
	"Unix time": "Unixtid",
	"calendar": "kalender",
	"Gregorian calendar": "Gregorianska kalendern",
	"Julian calendar": "Julianska kalendern",
	"\u66c6\u6ce8": "Kalenderanteckning",
	"\u4e2d\u570b": "Kina",
	"Loading %1%...": "Laddar %1%...",
	"finished": "klar",
	"No changes.": "Inga \u00e4ndringar.",
	"No page modified": "ingen sida modifierad",
	"\u4e2d\u6587\u6578\u5b57": "Till kinesiska siffror",
	"astronomy": "astronomi",
	"log-type-debug": "fels\u00f6kning",
	"log-type-em": "emfas",
	"log-type-error": "fel",
	"log-type-fatal": "kritisk",
	"log-type-info": "info",
	"log-type-log": "logg",
	"log-type-trace": "sp\u00e5r",
	"log-type-warn": "varna",
	"Not Yet Implemented!": "Inte \u00e4nnu implementerad!",
	"\u6240\u6307\u5b9a\u4e4b domain [%1] \u5c1a\u672a\u8f09\u5165\uff0c\u82e5\u6709\u5fc5\u8981\u8acb\u4f7f\u7528\u5f37\u5236\u8f09\u5165 flag\u3002": "Angiven dom\u00e4n [%1] har \u00e4nnu inte laddats. Du kan beh\u00f6va ange FORCE-flagga.",
	"Language": "Spr\u00e5k",
	"Content is empty": "Inneh\u00e5llet \u00e4r tomt",
	"Content is not settled": "Inneh\u00e5llet har inte etablerats",
	"Abandon change": "\u00d6verge \u00e4ndring",
	"No reason provided": "Ingen anledning gavs",
	"Continue key": "Forts\u00e4ttningsnyckel",
	"no change": "ingen \u00e4ndring",
	"finished: %1": "klar: %1",
	"%1 elapsed, %3 at %2": "%1 passerad, %3 vid %2",
	"First, it takes %1 to get %2 {{PLURAL:%2|page|pages}}.": "F\u00f6rst tar den %1 och f\u00e5r %2 sidor.",
	"%1 {{PLURAL:%2|page|pages}} processed": "%1 sidor bearbetade",
	"%1 {{PLURAL:%1|page|pages}} have not changed,": "%1 sidor har inte \u00e4ndrats,",
	"%1 elapsed.": "%1 passerad.",
	"'''Stopped''', give up editing.": "'''Stannade''', \u00f6verge redigering.",
	"function": "funktion",
	"number": "nummer",
	"Contents": "Inneh\u00e5ll",
	"%1 {{PLURAL:%1|year|years}} and %2 {{PLURAL:%2|month|months}}": "%1 \u00e5r %2 m",
	"%1 Y %2 M": "%1 \u00e5r %2 m",
	"%1 {{PLURAL:%1|year|years}}": "%1 \u00e5r",
	"%1 Y": "%1 \u00e5r",
	"%1 {{PLURAL:%1|month|months}}": "%1 m",
	"%1 M": "%1 m",
	"%1 {{PLURAL:%1|millisecond|milliseconds}}": "%1 ms",
	"%1 ms": "%1 ms",
	"%1 {{PLURAL:%1|second|seconds}}": "%1 s",
	"%1 s": "%1 s",
	"%1 {{PLURAL:%1|minute|minutes}}": "%1 min",
	"%1 min": "%1 min",
	"%1 {{PLURAL:%1|hour|hours}}": "%1 tm",
	"%1 hr": "%1 tm",
	"%1 {{PLURAL:%1|day|days}}": "%1 d",
	"%1 d": "%1 d",
	"2 days before yesterday, %H:%M": "I f\u00f6rrf\u00f6rrg\u00e5r, %H:%M",
	"the day before yesterday, %H:%M": "i f\u00f6rrg\u00e5r, %H:%M",
	"yesterday, %H:%M": "ig\u00e5r, %H:%M",
	"today, %H:%M": "idag, %H:%M",
	"tomorrow, %H:%M": "imorgon, %H:%M",
	"the day after tomorrow, %H:%M": "i \u00f6vermorgon, %H:%M",
	"2 days after tomorrow, %H:%M": "i \u00f6ver\u00f6vermorgon, %H:%M",
	"3 days after tomorrow, %H:%M": "om fyra dagar, %H:%M",
	"now": "nu",
	"several seconds ago": "flera sekunder sedan",
	"soon": "snart",
	"%1 {{PLURAL:%1|second|seconds}} ago": "%1 sekunder sen",
	"%1 {{PLURAL:%1|second|seconds}} later": "%1 sekunder senare",
	"%1 {{PLURAL:%1|minute|minutes}} ago": "%1 minuter sedan",
	"%1 {{PLURAL:%1|minute|minutes}} later": "%1 minuter senare",
	"%1 {{PLURAL:%1|hour|hours}} ago": "%1 timme sedan",
	"%1 {{PLURAL:%1|hour|hours}} later": "%1 timme senare",
	"%1 {{PLURAL:%1|day|days}} ago": "%1 dag sedan",
	"%1 {{PLURAL:%1|day|days}} later": "%1 dagar senare",
	"%1 {{PLURAL:%1|week|weeks}} ago": "%1 veckor sedan",
	"%1 {PLURAL:%1|week|weeks}} later": "%1 veckor senare",
	"\u5e74\u865f": "Datum i era",
	"\u8a3b": "Anteckning",
	"\u7d00\u5e74": "Erans namn",
	"\u8df3\u904e [%1]\uff1a\u672c[%2]\u50c5\u4f9b\u53c3\u7167\u7528\u3002": "Hoppa \u00f6ver [%1]: %2 ska bara anv\u00e4ndas f\u00f6r referenser.",
	"\u7409\u7403": "Ryukyu",
	"\u65e5\u672c": "Japan",
	"\ud55c\uad6d": "Korea",
	"B\u1eafc thu\u1ed9c": "Kinesisk dominans \u00f6ver Vietnam",
	"Th\u1eddi k\u1ef3 \u0111\u1ed9c l\u1eadp": "Sen dynastisk epok",
	"\u0e44\u0e17\u0e22": "Thailand",
	"India": "Indien",
	"Persia": "Persien",
	"\u039c\u03b1\u03ba\u03b5\u03b4\u03bf\u03bd\u03af\u03b1": "Makedonien",
	"\u1f08\u03b8\u1fc6\u03bd\u03b1\u03b9": "Klassiska Aten",
	"\u03a3\u03c0\u03ac\u03c1\u03c4\u03b7": "Sparta",
	"\u2191Back to TOC": "\u2191Tillbaka till inneh\u00e5llsf\u00f6rteckning",
	"Contents of [%1]": "Inneh\u00e5ll av [%1]",
	"expand": "visa",
	"collapse": "d\u00f6lj",
	"Illegal %1: [%2]": "Otill\u00e5ten %1: [%2]",
	"debug level": "fels\u00f6kningsniv\u00e5"
},
"sv-SE");
